==> owncloud_6.0.4~beta1%2Bdfsg.orig.tar.bz2: owncloud/apps/calendar/l10n/sk_SK.php <==
<?php $TRANSLATIONS = array(
"Not all calendars are completely cached" => "V pamäti nie sú úplne uložené všetky kalendáre",
"Everything seems to be completely cached" => "Zdá sa, že je všetko úplne uložené v pamäti",
"No calendars found." => "Nenašiel sa žiadny kalendár.",
"No events found." => "Nenašla sa žiadna udalosť.",
"Wrong calendar" => "Zlý kalendár",
"You do not have the permissions to edit this event." => "Nemáte oprávnenie pre úpravu tejto udalosti.",
"The file contained either no events or all events are already saved in your calendar." => "Súbor neobsahoval žiadne udalosti, alebo už sú všetky udalosti vo Vašom kalendári.",
"events has been saved in the new calendar" => "udalosti boli zapísané do nového kalendára",
"Import failed" => "Import zlyhal",
"events has been saved in your calendar" => "udalosti boli zapísané do kalendára",
"New Timezone:" => "Nová časová zóna:",
"Timezone changed" => "Časové pásmo zmenené",
"Invalid request" => "Neplatná požiadavka",
"Calendar" => "Kalendár",
"Deletion failed" => "Odstránenie zlyhalo",
"ddd d MMMM[ yyyy]{ - [ddd d] MMMM yyyy}" => "ddd d MMMM[ yyyy]{ - [ddd d] MMMM yyyy}",
"ddd d MMMM[ yyyy] HH:mm{ - [ ddd d MMMM yyyy] HH:mm}" => "ddd d MMMM[ yyyy] HH:mm{ - [ ddd d MMMM yyyy] HH:mm}",
"group" => "skupina",
"can edit" => "môže upraviť",
"ddd" => "ddd",
"ddd M/d" => "ddd M/d",
"dddd M/d" => "dddd M/d",
"MMMM yyyy" => "MMMM yyyy",
"MMM d[ yyyy]{ '–'[ MMM] d yyyy}" => "MMM d[ yyyy]{ '–'[ MMM] d yyyy}",
"dddd, MMM d, yyyy" => "dddd, MMM d, yyyy",
"Sunday" => "Nedeľa",
"Monday" => "Pondelok",
"Tuesday" => "Utorok",
"Wednesday" => "Streda",
"Thursday" => "Štvrtok",
"Friday" => "Piatok",
"Saturday" => "Sobota",
"Sun." => "Ned.",
"Mon." => "Pon.",
"Tue." => "Uto.",
"Wed." => "Str.",
"Thu." => "Štv.",
"Fri." => "Pia.",
"Sat." => "Sob.",
"January" => "Január",
"February" => "Február",
"March" => "Marec",
"April" => "Apríl",
"May" => "Máj",
"June" => "Jún",
"July" => "Júl",
"August" => "August",
"September" => "September",
"October" => "Október",
"November" => "November",
"December" => "December",
"Jan." => "Jan.",
"Feb." => "Feb.",
"Mar." => "Mar.",
"Apr." => "Apr.",
"May." => "Máj.",
"Jun." => "Jún.",
"Jul." => "Júl.",
"Aug." => "Aug.",
"Sep." => "Sep.",
"Oct." => "Okt.",
"Nov." => "Nov.",
"Dec." => "Dec.",
"All day" => "Celý deň",
"New Calendar" => "Nový kalendár",
"Missing or invalid fields" => "Chýbajúce alebo neplatné polia",
"Title" => "Názov",
"From Date" => "Od dátumu",
"From Time" => "Od času",
"To Date" => "Do dátumu",
"To Time" => "Do času",
"The event ends before it starts" => "Udalosť končí ešte pred tým než začne",
"There was a database fail" => "Nastala chyba databázy",
"Birthday" => "Narodeniny",
"Business" => "Podnikanie",
"Call" => "Hovor",
"Clients" => "Klienti",
"Deliverer" => "Doručovateľ",
"Holidays" => "Prázdniny",
"Ideas" => "Nápady",
"Journey" => "Cesta",
"Jubilee" => "Jubileá",
"Meeting" => "Stretnutia",
"Other" => "Ostatné",
"Personal" => "Osobné",
"Projects" => "Projekty",
"Questions" => "Otázky",
"Work" => "Práca",
"by" => "od",
"unnamed" => "nepomenovaný",
"You do not have the permissions to update this calendar." => "Nemáte oprávnenie pre vykonanie zmien v tomto kalendári.",
"You do not have the permissions to delete this calendar." => "Nemáte oprávnenie pre odstránenie kalendára.",
"You do not have the permissions to add to this calendar." => "Nemáte oprávnenie pre pridanie do tohto kalendára.",
"You do not have the permissions to add events to this calendar." => "Nemáte oprávnenie pre pridanie udalostí do tohto kalendára.",
"You do not have the permissions to delete this event." => "Nemáte oprávnenie pre odstránenie tejto udalosti.",
"Busy" => "Zaneprázdený",
"Does not repeat" => "Neopakovať",
"Daily" => "Denne",
"Weekly" => "Týždenne",
"Every Weekday" => "Každý deň v týždni",
"Bi-Weekly" => "Každý druhý týždeň",
"Monthly" => "Mesačne",
"Yearly" => "Ročne",
"never" => "nikdy",
"by occurrences" => "podľa výskytu",
"by date" => "podľa dátumu",
"by monthday" => "podľa dňa v mesiaci",
"by weekday" => "podľa dňa v týždni",
"events week of month" => "týždenné udalosti v mesiaci",
"first" => "prvý",
"second" => "druhý",
"third" => "tretí",
"fourth" => "štvrtý",
"fifth" => "piaty",
"last" => "posledný",
"by events date" => "podľa dátumu udalosti",
"by yearday(s)" => "po dňoch",
"by weeknumber(s)" => "podľa čísel týždňov",
"by day and month" => "podľa dňa a mesiaca",
"Contact birthdays" => "Narodeniny kontaktov",
"Date" => "Dátum",
"Cal." => "Kal.",
"Day" => "Deň",
"Week" => "Týždeň",
"Month" => "Mesiac",
"Today" => "Dnes",
"Settings" => "Nastavenia",
"Share Calendar" => "Zdielať kalendár",
"CalDav Link" => "CalDav odkaz",
"Download" => "Stiahnuť",
"Edit" => "Upraviť",
"Delete" => "Odstrániť",
"New calendar" => "Nový kalendár",
"Edit calendar" => "Upraviť kalendár",
"Displayname" => "Zobrazené meno",
"Calendar color" => "Farba kalendára",
"Save" => "Uložiť",
"Submit" => "Odoslať",
"Cancel" => "Zrušiť",
"Eventinfo" => "Informácie o udalosti",
"Repeating" => "Opakovanie",
"Alarm" => "Alarm",
"Attendees" => "Účastníci",
"Share" => "Zdielať",
"Title of the Event" => "Názov udalosti",
"from" => "z",
"All Day Event" => "Celodenná udalosť",
"Advanced options" => "Pokročilé možnosti",
"Location" => "Poloha",
"Edit categories" => "Úprava kategórií",
"Description" => "Popis",
"Repeat" => "Opakovať",
"Advanced" => "Pokročilé",
"Select weekdays" => "Do času",
"Select days" => "Vybrať dni",
"and the events day of year." => "a denné udalosti v roku.",
"and the events day of month." => "a denné udalosti v mesiaci.",
"Select months" => "Vybrať mesiace",
"Select weeks" => "Vybrať týždne",
"and the events week of year." => "a týždenné udalosti v roku.",
"Interval" => "Interval",
"End" => "Koniec",
"occurrences" => "výskyty",
"create a new calendar" => "vytvoriť nový kalendár",
"Import a calendar file" => "Importovať súbor kalendára",
"Please choose a calendar" => "Vybrať si kalendár",
"Name of new calendar" => "Meno nového kalendára",
"Take an available name!" => "Vybrať existujúce meno",
"A Calendar with this name already exists. If you continue anyhow, these calendars will be merged." => "Kalendár s rovnakým názvom už existuje. Pokračovaním kalendáre spojíte.",
"Remove all events from the selected calendar" => "Odstrániť všetky udalosti z vybraného kalendára",
"Import" => "Importovať",
"Close Dialog" => "Zatvoriť dialóg",
"Create a new event" => "Vytvoriť udalosť",
"Unshare" => "Nezdieľať",
"Send Email" => "Odoslať email",
"Shared via calendar" => "Zdieľané cez kalendár",
"View an event" => "Zobraziť udalosť",
"Category" => "Kategória",
"No categories selected" => "Žiadne vybraté kategórie",
"of" => "z",
"Access Class" => "Prístupová trieda",
"From" => "Od",
"at" => "v",
"To" => "Do",
"Your calendars" => "Vaše kalendáre",
"General" => "Všeobecné",
"Timezone" => "Časová zóna",
"Update timezone automatically" => "Automaticky aktualizovať časovú zónu",
"Time format" => "Formát času",
"24h" => "24h",
"12h" => "12h",
"Start week on" => "Týždeň začína v ",
"Cache" => "Vyrovnávacia pamäť",
"Clear cache for repeating events" => "Vymazať vyrovnávaciu pamäť pre opakujúce sa udalosti",
"URLs" => "Odkazy URL",
"Calendar CalDAV syncing addresses" => "Kalendár CalDAV synchronizuje adresy",
"more info" => "viac informácií",
"Primary address (Kontact et al)" => "Primárna adresa",
"iOS/OS X" => "iOS/OS X",
"Read only iCalendar link(s)" => "Odkazy na iCalendar (iba na čítanie)"
);

==> owncloud_7.0.0~beta1%2Bdfsg.orig.tar.bz2: owncloud/apps/calendar/l10n/sk_SK.php <==
<?php $TRANSLATIONS = array(
"Not all calendars are completely cached" => "V pamäti nie sú úplne uložené všetky kalendáre",
"Everything seems to be completely cached" => "Zdá sa, že je všetko úplne uložené v pamäti",
"No calendars found." => "Nenašiel sa žiadny kalendár.",
"No events found." => "Nenašla sa žiadna udalosť.",
"Wrong calendar" => "Zlý kalendár",
"You do not have the permissions to edit this event." => "Nemáte oprávnenie pre úpravu tejto udalosti.",
"The file contained either no events or all events are already saved in your calendar." => "Súbor neobsahoval žiadne udalosti, alebo už sú všetky udalosti vo vašom kalendári.",
"events has been saved in the new calendar" => "udalosti boli zapísané do nového kalendára",
"Import failed" => "Import zlyhal",
"events has been saved in your calendar" => "udalosti boli zapísané do vášho kalendára",
"New Timezone:" => "Nová časová zóna:",
"Timezone changed" => "Časové pásmo zmenené",
"Invalid request" => "Neplatná požiadavka",
"Calendar" => "Kalendár",
"Deletion failed" => "Odstránenie zlyhalo",
"ddd d MMMM[ yyyy]{ - [ddd d] MMMM yyyy}" => "ddd d MMMM[ yyyy]{ - [ddd d] MMMM yyyy}",
"ddd d MMMM[ yyyy] HH:mm{ - [ ddd d MMMM yyyy] HH:mm}" => "ddd d MMMM[ yyyy] HH:mm{ - [ ddd d MMMM yyyy] HH:mm}",
"group" => "skupina",
"can edit" => "môže upraviť",
"can share" => "môže zdieľať",
"ddd" => "ddd",
"ddd M/d" => "ddd M/d",
"dddd M/d" => "dddd M/d",
"MMMM yyyy" => "MMMM yyyy",
"MMM d[ yyyy]{ '–'[ MMM] d yyyy}" => "MMM d[ yyyy]{ '–'[ MMM] d yyyy}",
"dddd, MMM d, yyyy" => "dddd, MMM d, yyyy",
"Sunday" => "Nedeľa",
"Monday" => "Pondelok",
"Tuesday" => "Utorok",
"Wednesday" => "Streda",
"Thursday" => "Štvrtok",
"Friday" => "Piatok",
"Saturday" => "Sobota",
"Sun." => "Ned.",
"Mon." => "Pon.",
"Tue." => "Uto.",
"Wed." => "Str.",
"Thu." => "Štv.",
"Fri." => "Pia.",
"Sat." => "Sob.",
"January" => "Január",
"February" => "Február",
"March" => "Marec",
"April" => "Apríl",
"May" => "Máj",
"June" => "Jún",
"July" => "Júl",
"August" => "August",
"September" => "September",
"October" => "Október",
"November" => "November",
"December" => "December",
"Jan." => "Jan.",
"Feb." => "Feb.",
"Mar." => "Mar.",
"Apr." => "Apr.",
"May." => "Máj.",
"Jun." => "Jún.",
"Jul." => "Júl.",
"Aug." => "Aug.",
"Sep." => "Sep.",
"Oct." => "Okt.",
"Nov." => "Nov.",
"Dec." => "Dec.",
"All day" => "Celý deň",
"New Calendar" => "Nový kalendár",
"Missing or invalid fields" => "Chýbajúce alebo neplatné polia",
"Title" => "Názov",
"From Date" => "Od dátumu",
"From Time" => "Od času",
"To Date" => "Do dátumu",
"To Time" => "Do času",
"The event ends before it starts" => "Udalosť končí ešte pred tým než začne",
"There was a database fail" => "Vyskytla sa chyba databázy",
"Birthday" => "Narodeniny",
"Business" => "Podnikanie",
"Call" => "Hovor",
"Clients" => "Klienti",
"Deliverer" => "Doručovateľ",
"Holidays" => "Prázdniny",
"Ideas" => "Nápady",
"Journey" => "Cesta",
"Jubilee" => "Jubileá",
"Meeting" => "Stretnutia",
"Other" => "Ostatné",
"Personal" => "Osobné",
"Projects" => "Projekty",
"Questions" => "Otázky",
"Work" => "Práca",
"by" => "od",
"unnamed" => "nepomenovaný",
"You do not have the permissions to update this calendar." => "Nemáte oprávnenie pre vykonanie zmien v tomto kalendári.",
"You do not have the permissions to delete this calendar." => "Nemáte oprávnenie pre odstránenie kalendára.",
"You do not have the permissions to add to this calendar." => "Nemáte oprávnenie pre pridanie do tohto kalendára.",
"You do not have the permissions to add events to this calendar." => "Nemáte oprávnenie pre pridanie udalostí do tohto kalendára.",
"You cannot add non-public events to a shared calendar." => "Nie je možné pridať neverejné udalosti do zdieľaného kalendára.",
"You do not have the permissions to delete this event." => "Nemáte oprávnenie pre odstránenie tejto udalosti.",
"Busy" => "Zaneprázdený",
"Show full event" => "Zobraziť celú udalosť",
"Show only busy" => "Zobraziť len zaneprázdnené",
"Hide event" => "Skryť udalosť",
"Does not repeat" => "Neopakovať",
"Daily" => "Denne",
"Weekly" => "Týždenne",
"Every Weekday" => "Každý deň v týždni",
"Bi-Weekly" => "Každý druhý týždeň",
"Monthly" => "Mesačne",
"Yearly" => "Ročne",
"never" => "nikdy",
"by occurrences" => "podľa výskytu",
"by date" => "podľa dátumu",
"by monthday" => "podľa dňa v mesiaci",
"by weekday" => "podľa dňa v týždni",
"events week of month" => "týždenné udalosti v mesiaci",
"first" => "prvý",
"second" => "druhý",
"third" => "tretí",
"fourth" => "štvrtý",
"fifth" => "piaty",
"last" => "posledný",
"by events date" => "podľa dátumu udalosti",
"by yearday(s)" => "po dňoch",
"by weeknumber(s)" => "podľa čísel týždňov",
"by day and month" => "podľa dňa a mesiaca",
"Contact birthdays" => "Narodeniny kontaktov",
"Date" => "Dátum",
"Cal." => "Kal.",
"Day" => "Deň",
"Week" => "Týždeň",
"Month" => "Mesiac",
"Today" => "Dnes",
"CalDav Link" => "CalDav odkaz",
"Timezone" => "Časová zóna",
"Update timezone automatically" => "Automaticky aktualizovať časovú zónu",
"Time format" => "Formát času",
"24h" => "24h",
"12h" => "12h",
"Start week on" => "Týždeň sa začína v ",
"Cache" => "Vyrovnávacia pamäť",
"Clear cache for repeating events" => "Vymazať vyrovnávaciu pamäť pre opakujúce sa udalosti",
"Primary CalDAV address" => "Primárna CalDAV adresa",
"iOS/OS X CalDAV address" => "iOS/OS X CalDAV adresa",
"Share Calendar" => "Zdielať kalendár",
"Download" => "Stiahnuť",
"Edit" => "Upraviť",
"Delete" => "Odstrániť",
"New calendar" => "Nový kalendár",
"Edit calendar" => "Upraviť kalendár",
"Edit event" => "Upraviť udalosť",
"Save event" => "Uložiť udalosť",
"Delete event" => "Zmazať udalosť",
"Eventinfo" => "Informácie o udalosti",
"Repeating" => "Opakovanie",
"Alarm" => "Alarm",
"Attendees" => "Účastníci",
"Share" => "Zdielať",
"Title of the Event" => "Názov udalosti",
"from" => "od",
"to" => "do",
"All Day Event" => "Celodenná udalosť",
"Advanced options" => "Pokročilé možnosti",
"Location" => "Poloha",
"Categories (separate by comma)" => "Kategórie (oddelené čiarkou)",
"Edit categories" => "Upraviť kategórie",
"Description" => "Popis",
"Export event" => "Exportovať udalosť",
"Repeat" => "Opakovať",
"Advanced" => "Pokročilé",
"Select weekdays" => "Vybrať dni v týždni",
"Select days" => "Vybrať dni",
"and the events day of year." => "a denné udalosti v roku.",
"and the events day of month." => "a denné udalosti v mesiaci.",
"Select months" => "Vybrať mesiace",
"Select weeks" => "Vybrať týždne",
"and the events week of year." => "a týždenné udalosti v roku.",
"Interval" => "Interval",
"End" => "Koniec",
"occurrences" => "výskyty",
"Visibility to people shared with" => "Viditeľnosť pre používateľov, s ktorými je zdieľaná",
"create a new calendar" => "vytvoriť nový kalendár",
"Import a calendar file" => "Importovať súbor kalendára",
"Please choose a calendar" => "Vybrať si kalendár",
"Name of new calendar" => "Názov nového kalendára",
"Take an available name!" => "Vybrať existujúce meno",
"A Calendar with this name already exists. If you continue anyhow, these calendars will be merged." => "Kalendár s rovnakým názvom už existuje. Pokračovaním kalendáre spojíte.",
"Remove all events from the selected calendar" => "Odstrániť všetky udalosti z vybraného kalendára",
"Import" => "Importovať",
"Close Dialog" => "Zatvoriť dialóg",
"Create a new event" => "Vytvoriť udalosť",
"Create event" => "Vytvoriť udalosť",
"Share with user or group" => "Zdieľať s používateľom alebo skupinou",
"Unshare" => "Nezdieľať",
"Not shared with anyone" => "Nezdieľané s nikým",
"Send Email" => "Odoslať email",
"Shared via calendar" => "Zdieľané cez kalendár",
"Not shared with anyone via calendar" => "Nezdieľané s nikým prostredníctvom kalendára",
"View an event" => "Zobraziť udalosť",
"Category" => "Kategória",
"No categories selected" => "Žiadne vybraté kategórie",
"%s of %s" => "%s z %s",
"Access Class" => "Prístupová trieda",
"From" => "Od",
"at" => "v",
"To" => "Do"
);
